summaryrefslogtreecommitdiff
path: root/libs/ardour/port_insert.cc
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2007-06-27 20:23:48 +0000
committerDavid Robillard <d@drobilla.net>2007-06-27 20:23:48 +0000
commit05bcdd1d4c583c68ed977164913ff47e94df7adb (patch)
treeaea97d1d013b62116feb5ac77db4b5479ffb9b9e /libs/ardour/port_insert.cc
parent09264537c4baeabfc8eccddc1132ae8612a29555 (diff)
Renamed Insert to Processor and Redirect to IOProcessor.
git-svn-id: svn://localhost/ardour2/trunk@2071 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'libs/ardour/port_insert.cc')
-rw-r--r--libs/ardour/port_insert.cc22
1 files changed, 11 insertions, 11 deletions
diff --git a/libs/ardour/port_insert.cc b/libs/ardour/port_insert.cc
index 51bf8fb0fb..0c12c0ed2c 100644
--- a/libs/ardour/port_insert.cc
+++ b/libs/ardour/port_insert.cc
@@ -41,17 +41,17 @@ using namespace ARDOUR;
using namespace PBD;
PortInsert::PortInsert (Session& s, Placement p)
- : Redirect (s, string_compose (_("insert %1"), (bitslot = s.next_insert_id()) + 1), p, 1, -1, 1, -1)
+ : IOProcessor (s, string_compose (_("insert %1"), (bitslot = s.next_insert_id()) + 1), p, 1, -1, 1, -1)
{
init ();
- InsertCreated (this); /* EMIT SIGNAL */
+ ProcessorCreated (this); /* EMIT SIGNAL */
}
PortInsert::PortInsert (const PortInsert& other)
- : Redirect (other._session, string_compose (_("insert %1"), (bitslot = other._session.next_insert_id()) + 1), other.placement(), 1, -1, 1, -1)
+ : IOProcessor (other._session, string_compose (_("insert %1"), (bitslot = other._session.next_insert_id()) + 1), other.placement(), 1, -1, 1, -1)
{
init ();
- InsertCreated (this); /* EMIT SIGNAL */
+ ProcessorCreated (this); /* EMIT SIGNAL */
}
void
@@ -69,13 +69,13 @@ PortInsert::init ()
}
PortInsert::PortInsert (Session& s, const XMLNode& node)
- : Redirect (s, "unnamed port insert", PreFader)
+ : IOProcessor (s, "unnamed port insert", PreFader)
{
if (set_state (node)) {
throw failed_constructor();
}
- InsertCreated (this); /* EMIT SIGNAL */
+ ProcessorCreated (this); /* EMIT SIGNAL */
}
PortInsert::~PortInsert ()
@@ -110,7 +110,7 @@ PortInsert::get_state(void)
XMLNode&
PortInsert::state (bool full)
{
- XMLNode& node = Redirect::state(full);
+ XMLNode& node = IOProcessor::state(full);
char buf[32];
node.add_property ("type", "port");
snprintf (buf, sizeof (buf), "%" PRIu32, bitslot);
@@ -146,15 +146,15 @@ PortInsert::set_state(const XMLNode& node)
const XMLNode* insert_node = &node;
// legacy sessions: search for child Redirect node
for (niter = nlist.begin(); niter != nlist.end(); ++niter) {
- if ((*niter)->name() == "Redirect") {
+ if ((*niter)->name() == "IOProcessor") {
insert_node = *niter;
break;
}
}
- Redirect::set_state (*insert_node);
+ IOProcessor::set_state (*insert_node);
return 0;
}
@@ -227,7 +227,7 @@ PortInsert::configure_io (ChanCount in, ChanCount out)
bool success = (_io->ensure_io (out, in, false, this) == 0);
if (success)
- return Insert::configure_io(in, out);
+ return Processor::configure_io(in, out);
else
return false;
}
@@ -146,15 +146,15 @@ PortInsert::set_state(const XMLNode& node)
const XMLNode* insert_node = &node;
- // legacy sessions: search for child Redirect node
+ // legacy sessions: search for child IOProcessor node
for (niter = nlist.begin(); niter != nlist.end(); ++niter) {